Changelog
=========


1.0a2 (2020-06-11)
------------------

- Fix resources files in released package
  [MrTango]

- Support also Collections not only Folders
  [MrTango]


1.0a1 (2020-06-11)
------------------

- Initial release.
  [MrTango]
